@@ -1,6 +1,6 @@
 """Gets the work done - downloads media with flexible flow control"""
 
-import asyncio
+import tempfile
 from pathlib import Path
 
 import httpx
@@ -10,6 +10,7 @@ from throttlebuster.constants import DOWNLOAD_PART_EXTENSION
 from moviebox_api.cli.helpers import (
     get_caption_file_or_raise,
     perform_search_and_get_item,
+    stream_video_via_mpv,
 )
 from moviebox_api.constants import (
     CURRENT_WORKING_DIR,
@@ -28,7 +29,7 @@ from moviebox_api.download import (
     MediaFileDownloader,
     resolve_media_file_to_be_downloaded,
 )
-from moviebox_api.helpers import assert_instance, assert_membership
+from moviebox_api.helpers import assert_instance, assert_membership, get_event_loop
 from moviebox_api.models import SearchResultsItem
 
 __all__ = ["Downloader"]
@@ -59,6 +60,7 @@ class Downloader:
         language: tuple[str] = (DEFAULT_CAPTION_LANGUAGE,),
         download_caption: bool = False,
         caption_only: bool = False,
+        stream: bool = False,
         search_function: callable = perform_search_and_get_item,
         chunk_size: int = DEFAULT_CHUNK_SIZE,
         tasks: int = DEFAULT_TASKS,
@@ -70,7 +72,7 @@ class Downloader:
         DownloadedFile | httpx.Response | None,
         list[DownloadedFile | httpx.Response] | None,
     ]:
-        """Search movie by name and proceed to download it.
+        """Search movie by name and proceed to download it or stream it in VLC.
 
         Args:
             title (str): Complete or partial movie name
@@ -84,6 +86,7 @@ class Downloader:
             language (tuple, optional): Languages to download captions in. Defaults to (DEFAULT_CAPTION_LANGUAGE,).
             download_caption (bool, optional): Whether to download caption or not. Defaults to False.
             caption_only (bool, optional): Whether to ignore movie file or not. Defaults to False.
+            stream (bool, optional): Whether to stream directly in VLC instead of downloading. Defaults to False.
             search_function (callable, optional): Accepts `session`, `title`, `year`, `subject_type` & `yes` and returns `SearchResultsItem`.
             chunk_size (int, optional): Streaming download chunk size in kilobytes. Defaults to DEFAULT_CHUNK_SIZE.
             tasks (int, optional): Number of tasks to carry out the download. Defaults to DEFAULT_TASKS.
@@ -125,13 +128,15 @@ class Downloader:
 
         target_media_file = resolve_media_file_to_be_downloaded(quality, downloadable_details)
 
-        subtitle_details_items = []
+        subtitle_details_items: list[DownloadedFile] = []
+
+        subtitles_dir = tempfile.mkdtemp() if stream else caption_dir
 
         if download_caption or caption_only:
             for lang in language:
                 target_caption_file = get_caption_file_or_raise(downloadable_details, lang)
                 caption_downloader = CaptionFileDownloader(
-                    dir=caption_dir,
+                    dir=subtitles_dir,
                     chunk_size=chunk_size,
                     tasks=tasks,
                     part_dir=part_dir,
@@ -147,10 +152,13 @@ class Downloader:
 
                 subtitle_details_items.append(subtitle_details)
 
-            if caption_only:
+            if caption_only and not stream:
                 # terminate
                 return (None, subtitle_details_items)
 
+        if stream:
+            return stream_video_via_mpv(str(target_media_file.url), subtitle_details_items, subtitles_dir)
+
         movie_downloader = MediaFileDownloader(
             dir=dir,
             chunk_size=chunk_size,
@@ -180,6 +188,7 @@ class Downloader:
         language: tuple = (DEFAULT_CAPTION_LANGUAGE,),
         download_caption: bool = False,
         caption_only: bool = False,
+        stream: bool = False,
         limit: int = 1,
         search_function: callable = perform_search_and_get_item,
         chunk_size: int = DEFAULT_CHUNK_SIZE,
@@ -192,7 +201,7 @@ class Downloader:
         int,
         dict[str, DownloadedFile | httpx.Response | list[DownloadedFile | httpx.Response]],
     ]:
-        """Search tv-series by name and proceed to download its episodes.
+        """Search tv-series by name and proceed to download or stream its episodes.
 
         Args:
             title (str): Complete or partial tv-series name.
@@ -208,6 +217,7 @@ class Downloader:
             language (tuple, optional): Languages to download captions in. Defaults to (DEFAULT_CAPTION_LANGUAGE,).
             download_caption (bool, optional): Whether to download caption or not. Defaults to False.
             caption_only (bool, optional): Whether to ignore episode files or not. Defaults to False.
+            stream (bool, optional): Whether to stream directly in VLC instead of downloading. Defaults to False.
             limit (int, optional): Number of episodes to download including the offset episode. Defaults to 1.
             search_function (callable, optional): Accepts `session`, `title`, `year`, `subject_type` & `yes` and returns item.
             chunk_size (int, optional): Streaming download chunk size in kilobytes. Defaults to DEFAULT_CHUNK_SIZE.
@@ -246,8 +256,10 @@ class Downloader:
         downloadable_files = DownloadableTVSeriesFilesDetail(self._session, target_tv_series)
         response = {}
 
+        subtitles_dir = tempfile.mkdtemp() if stream else caption_dir
+
         caption_downloader = CaptionFileDownloader(
-            dir=caption_dir,
+            dir=subtitles_dir,
             chunk_size=chunk_size,
             tasks=tasks,
             part_dir=part_dir,
@@ -275,7 +287,7 @@ class Downloader:
             # - With regard to season details
 
             current_episode_details = {}
-            caption_details_items = []
+            caption_details_items: list[DownloadedFile] = []
 
             if caption_only or download_caption:
                 for lang in language:
@@ -296,16 +308,21 @@ class Downloader:
 
                     caption_details_items.append(caption_details)
 
-                if caption_only:
+                if caption_only and not stream:
                     # Avoid downloading tv-series
                     continue
 
-            # Download series
+            # Download or stream series
 
             current_episode_details["captions"] = caption_details_items
 
             target_media_file = resolve_media_file_to_be_downloaded(quality, downloadable_files_detail)
 
+            if stream:
+                stream_video_via_mpv(str(target_media_file.url), caption_details_items, subtitles_dir)
+
+                continue
+
             filename = media_file_downloader.generate_filename(
                 target_tv_series,
                 media_file=target_media_file,
@@ -330,8 +347,8 @@ class Downloader:
         DownloadedFile | httpx.Response | None,
         list[DownloadedFile | httpx.Response] | None,
     ]:
-        """Synchronously search movie by name and proceed to download it."""
-        return asyncio.get_event_loop().run_until_complete(self.download_movie(*args, **kwargs))
+        """Synchronously search movie by name and proceed to download or stream it."""
+        return get_event_loop().run_until_complete(self.download_movie(*args, **kwargs))
 
     def download_tv_series_sync(
         self,
@@ -341,5 +358,5 @@ class Downloader:
         int,
         dict[str, DownloadedFile | httpx.Response | list[DownloadedFile | httpx.Response]],
     ]:
-        """Synchronously search tv-series by name and proceed to download its episodes."""
-        return asyncio.get_event_loop().run_until_complete(self.download_tv_series(*args, **kwargs))
+        """Synchronously search tv-series by name and proceed to download or stream its episodes."""
+        return get_event_loop().run_until_complete(self.download_tv_series(*args, **kwargs))
