@@ -2,14 +2,17 @@
 
 import logging
 import random
+import shutil
+import subprocess
 
 import click
 from httpx import ConnectTimeout, HTTPStatusError
 from pydantic import ValidationError
-from throttlebuster import DownloadMode
+from throttlebuster import DownloadedFile, DownloadMode
 
 from moviebox_api import __repo__, logger
 from moviebox_api.constants import (
+    DOWNLOAD_REQUEST_HEADERS,
     ENVIRONMENT_HOST_KEY,
     HOST_URL,
     MIRROR_HOSTS,
@@ -78,8 +81,8 @@ async def perform_search_and_get_item(
         for pos, item in enumerate(items, start=1):
             if click.confirm(
                 f"> {message} ({pos}/{len(items)}) : "
-                f"{'[' + item.subjectType.name + '] ' if subject_type is SubjectType.ALL else ''}{item.title} "
-                f"{item.releaseDate.year, item.imdbRatingValue}"
+                f"{'[' + item.subjectType.name + '] ' if subject_type is SubjectType.ALL else ''}{item.title}"
+                f" {item.releaseDate.year, item.imdbRatingValue}"
             ):
                 return item
 
@@ -141,7 +144,7 @@ def get_caption_file_or_raise(
     return target_caption_file
 
 
-def prepare_start(quiet: bool, verbose: bool) -> None:
+def prepare_start(quiet: bool = False, verbose: int = 0) -> None:
     """Set up some stuff for better CLI usage such as:
 
     - Set higher logging level for some packages.
@@ -198,7 +201,7 @@ def show_any_help(exception: Exception, exception_msg: str) -> int:
     exit_code = 1
 
     if isinstance(exception, ConnectTimeout):
-        logging.info("Http connect request has timed out. Check your connection and retry.")
+        logging.info("Internet connection request has timed out. Check your connection and retry.")
 
     elif isinstance(exception, HTTPStatusError):
         match exception.response.status_code:
@@ -222,4 +225,47 @@ def show_any_help(exception: Exception, exception_msg: str) -> int:
             f"For instance: In Linux system you might run 'export {ENVIRONMENT_HOST_KEY}=\"{example_host}\"'"
         )
 
+    logging.info(f"Incase the error persist then feel free to submit the issue at {__repo__}/issues/new")
+
     return exit_code
+
+
+def stream_video_via_mpv(url: str, subtitle_details_items: list[DownloadedFile], subtitles_dir: str):
+    try:
+        # Create an MPV command with properly formatted headers
+        mpv_cmd = ["mpv"]
+        # Disable youtube-dl/yt-dlp since we're streaming a direct video URL
+        mpv_cmd.append("--no-ytdl")
+        for header_name, header_value in DOWNLOAD_REQUEST_HEADERS.items():
+            mpv_cmd.append(f"--http-header-fields={header_name}: {header_value}")
+
+        for index, sub_file in enumerate(subtitle_details_items):
+            if index == 0:
+                mpv_cmd.append("--sid=1")
+            # Convert to absolute path for mpv compatibility
+            subtitle_path = sub_file.saved_to.resolve().as_posix()
+            mpv_cmd.append(f"--sub-file={subtitle_path}")
+
+        mpv_cmd.append(str(url))
+
+        logging.info("Launching MPV with required headers and subtitles...")
+
+        logging.debug(f"MPV launch commands :  {' '.join(mpv_cmd)}")
+
+        subprocess.run(mpv_cmd)
+
+        shutil.rmtree(subtitles_dir, ignore_errors=True)
+
+        return (None, None)
+
+    except FileNotFoundError:
+        logging.error(
+            "MPV player not found. Please install MPV from https://mpv.io/installation/ "
+            "to use streaming feature. "
+        )
+
+        return (None, None)
+
+    except Exception as e:
+        logging.error(f"Error launching MPV: {e}")
+        return (None, None)
