@@ -22,9 +22,11 @@ from moviebox_api.cli.helpers import (
     process_download_runner_params,
     show_any_help,
 )
+from moviebox_api.cli.interactive import run_interactive_menu
 from moviebox_api.constants import (
     CURRENT_WORKING_DIR,
     DEFAULT_CHUNK_SIZE,
+    DEFAULT_READ_TIMEOUT_ATTEMPTS,
     DEFAULT_TASKS,
     DEFAULT_TASKS_LIMIT,
     DOWNLOAD_PART_EXTENSION,
@@ -35,6 +37,7 @@ from moviebox_api.download import (
     CaptionFileDownloader,
     MediaFileDownloader,
 )
+from moviebox_api.helpers import get_event_loop
 
 __all__ = [
     "download_movie_command",
@@ -43,6 +46,7 @@ __all__ = [
     "homepage_content_command",
     "popular_search_command",
     "item_details_command",
+    "interactive_menu_command",
 ]
 
 DEBUG = os.getenv("DEBUG", "0") == "1"
@@ -149,6 +153,14 @@ def moviebox():
     default=DEFAULT_CHUNK_SIZE,
     show_default=True,
 )
+@click.option(
+    "-R",
+    "--timeout-retry-attempts",
+    type=click.INT,
+    help="Number of times to retry download upon read request timing out",
+    show_default=True,
+    default=DEFAULT_READ_TIMEOUT_ATTEMPTS,
+)
 @click.option(
     "-B",
     "--merge-buffer-size",
@@ -177,7 +189,7 @@ def moviebox():
 )
 @click.option(
     "--leave/--no-leave",
-    default=True,
+    default=False,
     help="Keep all leaves of the progress-bar",
     show_default=True,
 )
@@ -224,6 +236,12 @@ def moviebox():
     is_flag=True,
     help="Do not prompt for movie confirmation",
 )
+@click.option(
+    "-X",
+    "--stream",
+    is_flag=True,
+    help="Stream directly in MPV instead of downloading",
+)
 @click.help_option("-h", "--help")
 def download_movie_command(
     title: str,
@@ -239,14 +257,15 @@ def download_movie_command(
     verbose: int,
     quiet: bool,
     yes: bool,
+    stream: bool = False,
     **download_runner_params,
 ):
-    """Search and download movie."""
+    """Search and download or stream movie."""
 
     prepare_start(quiet, verbose=verbose)
 
     downloader = Downloader()
-    asyncio.get_event_loop().run_until_complete(
+    get_event_loop().run_until_complete(
         downloader.download_movie(
             title,
             year=year,
@@ -259,6 +278,7 @@ def download_movie_command(
             caption_only=caption_only,
             movie_filename_tmpl=movie_filename_tmpl,
             caption_filename_tmpl=caption_filename_tmpl,
+            stream=stream,
             **process_download_runner_params(download_runner_params),
         )
     )
@@ -280,6 +300,7 @@ def download_movie_command(
     type=click.IntRange(1, 1000),
     help="TV Series season filter",
     required=True,
+    prompt="> Enter season number",
 )
 @click.option(
     "-e",
@@ -287,6 +308,7 @@ def download_movie_command(
     type=click.IntRange(1, 1000),
     help="Episode offset of the tv-series season",
     required=True,
+    prompt="> Enter episode number",
 )
 @click.option(
     "-l",
@@ -381,6 +403,14 @@ def download_movie_command(
     default=DEFAULT_CHUNK_SIZE,
     show_default=True,
 )
+@click.option(
+    "-R",
+    "--timeout-retry-attempts",
+    type=click.INT,
+    help="Number of times to retry download upon read request timing out",
+    show_default=True,
+    default=DEFAULT_READ_TIMEOUT_ATTEMPTS,
+)
 @click.option(
     "-B",
     "--merge-buffer-size",
@@ -409,7 +439,7 @@ def download_movie_command(
 )
 @click.option(
     "--leave/--no-leave",
-    default=True,
+    default=False,
     help="Keep all leaves of the progressbar",
     show_default=True,
 )
@@ -456,6 +486,12 @@ def download_movie_command(
     is_flag=True,
     help="Do not prompt for tv-series confirmation",
 )
+@click.option(
+    "-X",
+    "--stream",
+    is_flag=True,
+    help="Stream directly in MPV instead of downloading",
+)
 @click.help_option("-h", "--help")
 def download_tv_series_command(
     title: str,
@@ -474,14 +510,15 @@ def download_tv_series_command(
     verbose: int,
     quiet: bool,
     yes: bool,
+    stream: bool = False,
     **download_runner_params,
 ):
-    """Search and download tv series."""
+    """Search and download or stream tv series."""
 
     prepare_start(quiet, verbose=verbose)
 
     downloader = Downloader()
-    asyncio.get_event_loop().run_until_complete(
+    get_event_loop().run_until_complete(
         downloader.download_tv_series(
             title,
             year=year,
@@ -497,11 +534,19 @@ def download_tv_series_command(
             limit=limit,
             episode_filename_tmpl=episode_filename_tmpl,
             caption_filename_tmpl=caption_filename_tmpl,
+            stream=stream,
             **process_download_runner_params(download_runner_params),
         )
     )
 
 
+@click.command(context_settings=command_context_settings)
+@click.help_option("-h", "--help")
+def interactive_menu_command():
+    """Launch interactive menu interface."""
+    run_interactive_menu()
+
+
 def main():
     """Entry point"""
     try:
@@ -511,6 +556,7 @@ def main():
         moviebox.add_command(homepage_content_command, "homepage-content")
         moviebox.add_command(popular_search_command, "popular-search")
         moviebox.add_command(item_details_command, "item-details")
+        moviebox.add_command(interactive_menu_command, "interactive")
         return moviebox()
 
     except Exception as e:
