@@ -7,7 +7,7 @@ from pathlib import Path
 
 from throttlebuster.constants import (
     DEFAULT_CHUNK_SIZE,
-    DEFAULT_TASKS,
+    DEFAULT_READ_TIMEOUT_ATTEMPTS,
     DEFAULT_TASKS_LIMIT,
     DOWNLOAD_PART_EXTENSION,
     DownloadMode,
@@ -59,11 +59,13 @@ DEFAULT_REQUEST_HEADERS = {
 }
 """For general http requests other than download"""
 
+DOWNLOAD_REQUEST_REFERER = "https://fmoviesunblocked.net/"
+
 DOWNLOAD_REQUEST_HEADERS = {
     "Accept": "*/*",  # "video/webm,video/ogg,video/*;q=0.9,application/ogg;q=0.7,audio/*;q=0.6,*/*;q=0.5",
     "User-Agent": "Mozilla/5.0 (X11; Linux x86_64; rv:137.0) Gecko/20100101 Firefox/137.0",
     "Origin": SELECTED_HOST,
-    "Referer": HOST_URL,
+    "Referer": DOWNLOAD_REQUEST_REFERER,
 }
 """For media and subtitle files download requests"""
 
@@ -93,6 +95,10 @@ ITEM_DETAILS_PATH = "/detail"
 """Immediate path to particular item details page"""
 
 
+DEFAULT_TASKS = 5
+"""Default number of connections for download"""
+
+
 class SubjectType(IntEnum):
     """Content types mapped to their integer representatives"""
 
@@ -105,9 +111,14 @@ class SubjectType(IntEnum):
     MUSIC = 6
     """Music contents only"""
 
+    UNKNOWN_1 = 5
+    """Yet to be known"""
+
     UNKNOWN = 7
     """Yet to be known"""
 
+    # TODO: Research and update UNKNOWNS
+
     @classmethod
     def map(cls) -> dict[str, int]:
         """Content-type names mapped to their int representatives"""
