@@ -15,6 +15,7 @@ from moviebox_api._bases import (
 from moviebox_api.constants import (
     CURRENT_WORKING_DIR,
     DEFAULT_CHUNK_SIZE,
+    DEFAULT_READ_TIMEOUT_ATTEMPTS,
     DEFAULT_TASKS,
     DOWNLOAD_PART_EXTENSION,
     DOWNLOAD_QUALITIES,
@@ -67,7 +68,7 @@ def resolve_media_file_to_be_downloaded(
             target_metadata = downloadable_metadata.best_media_file
         case "WORST":
             target_metadata = downloadable_metadata.worst_media_file
-        case "_":
+        case _:
             if quality in DOWNLOAD_QUALITIES:
                 quality_downloads_map = downloadable_metadata.get_quality_downloads_map()
                 target_metadata = quality_downloads_map.get(quality)
@@ -176,19 +177,19 @@ class MediaFileDownloader(BaseFileDownloaderAndHelper):
 
     request_headers = DOWNLOAD_REQUEST_HEADERS
     request_cookies = {}
-    movie_filename_template = "%(title)s (%(release_year)d) - %(resolution)dP.%(ext)s"
-    series_filename_template = "%(title)s S%(season)dE%(episode)d - %(resolution)dP.%(ext)s"
+    movie_filename_template = "{title} {release_year} - {resolution}P.{ext}"
+    series_filename_template = "{title} S{season}E{episode} - {resolution}P.{ext}"
     # Should have been named episode_filename_template but for consistency
     # with the subject-types {movie, tv-series, music} it's better as it is
     possible_filename_placeholders = (
-        "%(title)s",
-        "%(release_year)d",
-        "%(release_date)s",
-        "%(resolution)d",
-        "%(ext)s",
-        "%(size_string)s",
-        "%(season)d",
-        "%(episode)d",
+        "{title}",
+        "{release_year}",
+        "{release_date}",
+        "{resolution}",
+        "{ext}",
+        "{size_string}",
+        "{season}",
+        "{episode}",
     )
 
     def __init__(
@@ -265,13 +266,13 @@ class MediaFileDownloader(BaseFileDownloaderAndHelper):
             episode=episode,
         )
 
-        filename_template = (
+        filename_template: str = (
             cls.series_filename_template
             if search_results_item.subjectType == SubjectType.TV_SERIES
             else cls.movie_filename_template
         )
 
-        return filename_template % placeholders
+        return filename_template.format(**placeholders)
 
     async def run(
         self,
@@ -282,6 +283,7 @@ class MediaFileDownloader(BaseFileDownloaderAndHelper):
         disable_progress_bar: bool = None,
         file_size: int = None,
         keep_parts: bool = False,
+        timeout_retry_attempts: int = DEFAULT_READ_TIMEOUT_ATTEMPTS,
         colour: str = "cyan",
         simple: bool = False,
         test: bool = False,
@@ -299,6 +301,7 @@ class MediaFileDownloader(BaseFileDownloaderAndHelper):
             disable_progress_bar (bool, optional): Do not show progress_bar. Defaults to None (decide based on progress_hook).
             file_size (int, optional): Size of the file to be downloaded. Defaults to None.
             keep_parts (bool, optional): Whether to retain the separate download parts. Defaults to False.
+            timeout_retry_attempts (int, optional): Number of times to retry download upon read request timing out. Defaults to DEFAULT_READ_TIMEOUT_ATTEMPTS.
             leave (bool, optional): Keep all leaves of the progressbar. Defaults to True.
             colour (str, optional): Progress bar display color. Defaults to "cyan".
             simple (bool, optional): Show percentage and bar only in progressbar. Deafults to False.
@@ -326,6 +329,7 @@ class MediaFileDownloader(BaseFileDownloaderAndHelper):
             disable_progress_bar=disable_progress_bar,
             file_size=file_size,
             keep_parts=keep_parts,
+            timeout_retry_attempts=timeout_retry_attempts,
             colour=colour,
             simple=simple,
             test=test,
@@ -340,22 +344,22 @@ class CaptionFileDownloader(BaseFileDownloaderAndHelper):
     request_headers = DOWNLOAD_REQUEST_HEADERS
     request_cookies = {}
     movie_filename_template = (
-        "%(title)s (%(release_year)d) - %(lanName)s.%(ext)s"
-        # "%(title)s (%(release_year)d) - %(lanName)s [delay - %(delay)d].%(ext)s"
+        "{title} ({release_year}) - {lanName}.{ext}"
+        # "{title} ({release_year}) - {lanName} [delay - {delay}].{ext}"
     )
-    series_filename_template = "%(title)s S%(season)dE%(episode)d - %(lanName)s.%(ext)s"
+    series_filename_template = "{title} S{season}E{episode} - {lanName}.{ext}"
     possible_filename_placeholders = (
-        "%(title)s",
-        "%(release_year)d",
-        "%(release_date)s",
-        "%(ext)s",
-        "%(size_string)s",
-        "%(id)s",
-        "%(lan)s",
-        "%(lanName)s",
-        "%(delay)d",
-        "%(season)d",
-        "%(episode)d",
+        "{title}",
+        "{release_year}",
+        "{release_date}",
+        "{ext}",
+        "{size_string}",
+        "{id}",
+        "{lan}",
+        "{lanName}",
+        "{delay}",
+        "{season}",
+        "{episode}",
     )
 
     def __init__(
@@ -436,12 +440,12 @@ class CaptionFileDownloader(BaseFileDownloaderAndHelper):
             episode=episode,
         )
 
-        filename_template = (
+        filename_template: str = (
             cls.series_filename_template
             if search_results_item.subjectType == SubjectType.TV_SERIES
             else cls.movie_filename_template
         )
-        return sanitize_filename(filename_template % placeholders)
+        return sanitize_filename(filename_template.format(**placeholders))
 
     async def run(
         self,
