@@ -135,7 +135,7 @@ class ContentCategoryModel(BaseModel):
 class HomepageContentModel(BaseModel):
     """Main model for home contents
 
-    - Movies/series available under path operatingList[0].banner.items
+    - Movies/series available under path `operatingList[0].banner.items`
     """
 
     topPickList: list
