@@ -1,22 +1,30 @@
-import pytest
 import asyncio
+from pathlib import Path
+
+import pytest
+
+from moviebox_api.core import Search, SubjectType
 from moviebox_api.requests import Session
-from moviebox_api.core import Search
-from moviebox_api.core import SubjectType
 
-keyword = "Titanic"
+project_dir = Path(__file__).parent.parent
 
-MOVIE_KEYWORD = keyword
+query = "Titanic"
+
+MOVIE_KEYWORD = query
 
 TV_SERIES_KEYWORD = "Merlin"
 
 
 def init_search(
-    session:Session, keyword=keyword, subject_type=SubjectType.ALL, per_page=4, page=1
+    session: Session,
+    query=query,
+    subject_type=SubjectType.ALL,
+    per_page=4,
+    page=1,
 ) -> Search:
     return Search(
         session=session,
-        keyword=keyword,
+        query=query,
         subject_type=subject_type,
         per_page=per_page,
         page=page,
